import { LogLevel } from '../model/log-level';
/**
 * Packer logger class.
 * Log messages depending on the log level.
 */
export declare class Logger {
    static readonly level: LogLevel;
    /**
     * Create logger instance with task name.
     * @param taskName
     */
    static create(taskName: string): Logger;
    readonly taskName: string;
    private constructor();
    /**
     * Get formatted current time.
     */
    static readonly currentTime: string;
    /**
     * Log error message.
     * @param message log message with console format expressions.
     * @param optionalParams Optional arguments to message.
     */
    error(message: string, ...optionalParams: any[]): void;
    /**
     * Log warning message.
     * @param message log message with console format expressions.
     * @param optionalParams Optional arguments to message.
     */
    warn(message: string, ...optionalParams: any[]): void;
    /**
     * Log info message.
     * @param message log message with console format expressions.
     * @param optionalParams Optional arguments to message.
     */
    info(message: string, ...optionalParams: any[]): void;
    /**
     * Log trace message.
     * @param message log message with console format expressions.
     * @param optionalParams Optional arguments to message.
     */
    trace(message: string, ...optionalParams: any[]): void;
}
export default Logger;
