import { PackerConfig } from '../model/packer-config';
import { PackageConfig } from '../model/package-config';
import { BabelConfig } from '../model/babel-config';
import { Logger } from '../common/logger';
/**
 * Metadata reader class.
 */
declare class MetaData {
    private packerConfig;
    private packageConfig;
    private babelConfig;
    private bannerTemplate;
    private packerHelpSummary;
    private packerBanner;
    /**
     * Fetch packer configuration object.
     * Return if already exist in cache, else read -> validate -> sanitize configuration data.
     * Configuration read logic will lookup for all extend packer config paths and merged configuration
     * from base to local order.
     * @param log Logger reference.
     */
    fetchPackerConfig(log: Logger): void;
    /**
     * Read and cache packer configuration.
     * @param log Logger reference.
     */
    readPackerConfig(log: Logger): PackerConfig;
    /**
     * Read and cache local package.json file configuration.
     */
    readPackageData(): PackageConfig;
    /**
     * Read and cache babel configuration.
     */
    readBabelConfig(): BabelConfig;
    /**
     * Read and cache banner template.
     */
    readBannerTemplate(): Promise<string>;
    /**
     * Read and cache packer help summary.
     */
    readPackerHelpSummary(): Promise<string>;
    /**
     * Read and cache packer banner.
     */
    readPackerBanner(): Promise<string>;
    /**
     * Read packer configuration path.
     * Use dynamic packer config path if available, else use .packerrc.js config in project root.
     * @param log Logger reference.
     */
    private readConfigPath;
    /**
     * Replace extension glob pattern with actual extension.
     * @param extGlob Extension glob.
     * @param command Target command.
     */
    private replaceExtensionGlob;
}
/**
 * Export static meta instance.
 */
export declare const meta: MetaData;
export {};
